#
# spec file for package prometheus-hanadb_exporter
#
# Copyright (c) 2019-2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

%if 0%{?suse_version} < 1500
%bcond_with test
%else
%bcond_without test
%endif

%define _prefix /usr
%define oldsyscondir /etc
%define _sysconfdir %{_prefix}/etc

Name:           prometheus-hanadb_exporter
Version:        0.7.3+git.1604318097.c2b074f
Release:        lp152.2.6.1
Summary:        SAP HANA database metrics exporter
License:        Apache-2.0
Group:          System/Monitoring
Url:            https://github.com/SUSE/hanadb_exporter
Source:         %{name}-%{version}.tar.gz
%if %{with test}
BuildRequires:  python3-pytest
%endif
BuildRequires:  python3-setuptools
Provides:       hanadb_exporter = %{version}-%{release}
BuildRequires:  fdupes
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       python3-shaptools >= 0.3.2
Requires:       python3-prometheus_client >= 0.6.0
BuildArch:      noarch

%description
SAP HANA database metrics exporter

%define shortname hanadb_exporter

%prep
%setup -q -n %{name}-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --root %{buildroot} --prefix=%{_prefix}
%fdupes %{buildroot}%{python3_sitelib}
# do not install tests
rm -r %{buildroot}%{python3_sitelib}/tests

# Add daemon files
mkdir -p %{buildroot}%{oldsyscondir}/%{shortname}
mkdir -p %{buildroot}%{_sysconfdir}/%{shortname}
install -D -m 644 daemon/%{shortname}@.service %{buildroot}%{_unitdir}/%{name}@.service

install -D -m 0644 config.json.example %{buildroot}%{_docdir}/%{name}/config.json.example
install -D -m 0644 metrics.json %{buildroot}%{_docdir}/%{name}/metrics.json
install -D -m 0644 logging_config.ini %{buildroot}%{_docdir}/%{name}/logging_config.ini

%post
%service_add_post %{name}@.service
rm -rf  %{_sysconfdir}/%{shortname}/*
ln -s %{_docdir}/%{name}/config.json.example %{_sysconfdir}/%{shortname}/config.json.example
ln -s %{_docdir}/%{name}/metrics.json  %{_sysconfdir}/%{shortname}/metrics.json
ln -s %{_docdir}/%{name}/logging_config.ini  %{_sysconfdir}/%{shortname}/logging_config.ini

%pre
%service_add_pre %{name}@.service

%preun
%service_del_preun %{name}@.service

%postun
%service_del_postun %{name}@.service

%if %{with test}
%check
pytest tests
%endif

%files
%defattr(-,root,root,-)
%if 0%{?sle_version:1} && 0%{?sle_version} < 120300
%doc README.md docs/METRICS.md LICENSE
%else
%doc README.md docs/METRICS.md
%license LICENSE
%endif
%{python3_sitelib}/*
%{_bindir}/%{shortname}

%dir %{_sysconfdir}
%dir %{oldsyscondir}/%{shortname}
%dir %{_sysconfdir}/%{shortname}
%{_docdir}/%{name}/config.json.example
%{_docdir}/%{name}/metrics.json
%{_docdir}/%{name}/logging_config.ini
%{_unitdir}/%{name}@.service

%changelog
* Mon Nov  2 2020 UTC - shap-staff@suse.de
- Release 0.7.3
  - Fix systemd macros usage in spec file (https://github.com/SUSE/hanadb_exporter/pull/81)
  (bsc#1178339)
* Thu Oct  1 2020 UTC - shap-staff@suse.de
- Release 0.7.2
  [#] Added
  - lookup for `/usr/etc` and  the fallback `/etc` directory for config files. ( https://github.com/SUSE/hanadb_exporter/pull/78)
* Tue May  5 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.7.1 Fix the case where HELP and TYPE entries are exported
  even though there is not any record for that metric (bsc#1170717)
  (jsc#SLE-10902, jsc#SLE-10903, jsc#ECO-817, jsc#ECO-818)
* Wed Apr 29 2020 Julien ADAMEK <julien.adamek@suse.com>
- Fix and improve the README file (bsc#1170843)
* Tue Feb 11 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.7.0 created
- Rename the rpm package to prometheus-hanadb_exporter to follow
  the prometheus conventions
- Update the default port from 8001 to 9668
  (jsc#SLE-10545)
* Wed Jan 15 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.6.1 Fix use case where TENANT_DATA_QUERY query
  returns columns with invalid values (0 number)
* Tue Dec 10 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.6.0 Change configuration files location from /etc
  to /usr/etc
* Tue Dec 10 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.3 Improve metrics collection if some of the rows
  result is None. Before, if any result was None the result was
  not exported. Now, only metrics with None value are ommitted
* Mon Dec  9 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.2 Add the option to use the hanadb_exporter with
  the stored user key. This gives the option to avoid the plain
  user/password strings usage.
* Wed Nov  6 2019 Diego Akechi <dakechi@suse.com>
- Version 0.5.1 Add the SAP HANA current alerts rating metric.
  This metric expose the current triggered alerts coming from
  inside the database and the rating (severity) of them. The rating
  is classified between 1 and 5.
* Fri Oct 25 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.0 Add the option to export metrics from multiple
  databases/tenants
* Thu Oct 24 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.4.1 Add new metadata labels to the metrics (sid, instance
  number and databse name)
* Wed Oct 23 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.4.0 Remove the factory usage to gain simplicity as only
  the prometheus exporter is used
* Tue Oct 22 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.4 Add reconnection to the database to avoid issues
  when the hana database is stopped and restarted
* Wed Aug  7 2019 Ayoub Belarbi <abelarbi@suse.de>
- Version 0.3.3 Better handling of query failures and incorrect labels
  and values
* Tue Jul  9 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.3.2 adding the option to filter the queries by current
  SAP HANA database version
* Wed Jul  3 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.3.1 updating how the exporter is executed as a daemon
* Tue Jul  2 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.3.0 created
- Code to manage the metrics updated to have a more generic usage
- metrics.json file structure updated to add more additional information
- Documentation created to explain how to create/update the metrics.json
  file
* Mon Jul  1 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.2.2 created with a new logging system
* Wed Jun 19 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.2.1 created
- Systemd support added to daemonize the execution
* Thu Jun 13 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version 0.2.0 created
- Improve the hanadb_exporter to retreive the metrics data from a
  configuration file
- Label correctly the imported metrics
* Wed Jun 12 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- First package version 0.1.0
